# Views

These examples show some of the common views that Dashport programs can implement like scrolling panels, scrolling text on the main screen, support for multiple views, and implementing an interactive prompt.

## Multiple Views

Multiple views can be accomplished by using keyboard controls and functions to switch between two screen states. The [multiple_views.py](https://github.com/numbertheory/dashport/blob/main/examples/views/multiple_views.py) example in the examples folder gives a good example of an app that puts all the output into functions that are called by the user typing the bound keys (in this case, "3" and "4").
